Module for building Python Projects in Pytools course. 

That course is provided by PythonPro, and is about how we can contribute to open source projects

[![Updates](https://pyup.io/repos/github/ClaraSantosmf/NewClass/shield.svg)](https://pyup.io/repos/github/ClaraSantosmf/NewClass/)
[![Python 3](https://pyup.io/repos/github/ClaraSantosmf/NewClass/python-3-shield.svg)](https://pyup.io/repos/github/ClaraSantosmf/NewClass/)

Supported Python 3 Version. 

For install

```Console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

To check code quality

```console 
flake8
```
Topics to be covered
1. Git
2. Virtualenv
3. Pip

